//*----------------------------------------------------------------------------
//* LCD.H
//*----------------------------------------------------------------------------
#ifndef __LCD_H
#define __LCD_H
//*----------------------------------------------------------------------------
#include "tools.h"
//*----------------------------------------------------------------------------
// KONSTANTEN
//*----------------------------------------------------------------------------
#define ORIENTATION_NORMAL  false
#define ORIENTATION_REVERSE true
//*----------------------------------------------------------------------------
#define LCD_WIDTH   128
#define LCD_HEIGHT  64
//*----------------------------------------------------------------------------
#define FILLED      true
#define FRAMED      false
//*----------------------------------------------------------------------------
#define TXT_MODE_LEFT     0x00
#define TXT_MODE_CENTER   0x01
#define TXT_MODE_RIGHT    0x02

#define TXT_MODE_NONINV   0x00
#define TXT_MODE_INVERS   0x04

#define TXT_MODE_RAM      0x00
#define TXT_MODE_FLASH    0x08

#define TXT_ADD_UP        0x10
#define TXT_ADD_DOWN      0x20
//*----------------------------------------------------------------------------
// MACROS
//*----------------------------------------------------------------------------
#define Lcd_Select()        PORTB &= ~BIT(LCD_CS)
#define Lcd_Deselect()      PORTB |= BIT(LCD_CS)
#define Lcd_A0_LO()         PORTB &= ~BIT(LCD_A0)
#define Lcd_A0_HI()         PORTB |= BIT(LCD_A0)
#define Lcd_Reset_HI()      PORTB |= BIT(LCD_RST)
//*----------------------------------------------------------------------------
// VARIABLENDEFINITION
//*----------------------------------------------------------------------------
// Der Font-Header fr den Font-Editor von H.Reddmann
// Funktioniert nur mit unkomprimierten Fonts
//*----------------------------------------------------------------------------
typedef struct {
  U8  Font_Size_Lo;       // Font size in Bytes LOW
  U8  Font_Size_Hi;       // Font size in Bytes HIGH
  U8  Font_Width;         // Font Width in Pixels
  U8  Font_Height;        // Font Height in Pixels
  U8  Font_BitsPerPixels; // Font Bits per Pixels (nur 1 erlaubt)
  U8  Font_FirstChar;     // Font first char
  U8  Font_LastChar;      // Font last char
} TFONTHEAD;
//*----------------------------------------------------------------------------
typedef struct {
  U8   Mirror[128][8];    // Display Mirror-Buffer 4 x 132 Bytes
  bool invers;            // Flag fr invertiertes Display
  U8 *fontwidth;          // Zeiger auf die Font-Breitentabelle
  U8 *fontdata;           // Zeiger auf die Font-Daten
  U8 Char_First;          // First Char aus Header
  U8 Char_Last;           // Last Char aus Header
  U8 Font_Height;         // Font Height aus Header
  U8 X_Pos;               // Aktuelle Zeichenausgabe X-Position
  U8 X_Max;               // Rechte Begrenzung fr Zeichenausgabe
  U8 Y_Pos;               // Aktuelle Zeichenausgabe Y-Position
} TLCD;

extern TLCD lcd;
//*----------------------------------------------------------------------------
// FUNKTIONSPROTOTYPEN
//*----------------------------------------------------------------------------
void Lcd_Init(void);
void Lcd_Show(void);
void Lcd_Clear(void);
void Lcd_SetContDir(U8 cont, bool dir);
void Lcd_SetPixel(u8 x, u8 y);
void Lcd_ClrPixel(U8 x, U8 y);
void Lcd_Hline(U8 x1, U8 y1, U8 w);
void Lcd_Vline(U8 x, U8 y, u8 h);
void Lcd_Erase(u8 x, u8 y, u8 w, u8 h);
void Lcd_Rectangle(u8 x, u8 y, u8 w, u8 h, u8 mode);
void Lcd_RoundRectangle(u8 x, u8 y, u8 w, u8 h, u8 mode);
void Lcd_Bar(U8 x, U8 y, U8 w, U8 max, U8 pos);
//*----------------------------------------------------------------------------
void Font_Init(U8 *ptr);
void Font_DrawChar(char c);
U8   Font_CharWidth(char c);
U16  Font_TextWidth(char *ptr, U8 mode);
void Font_TextOut(char *ptr, U8 x, U8 y, U8 mode);
void Font_TextPrint(char *ptr, u8 x, u8 y, u8 w, u8 mode);
void Font_TextFormat(char *ptr, u8 x, u8 y, u8 w);
void Font_HexNibble(U8 b);
void Font_Hex16(U16 b);
void Font_Hex32(U32 b);
void rprintfFloat(char numDigits, double x);
void rprintfNum(char base, char numDigits, char isSigned, char padchar, long n);
void rprintfStr(char str[]);
void rprintfStrLen(char str[], unsigned int start, unsigned int len);
void Font_Hex(U8 b);
void Font_Dez3(U8 b);
void Font_SetPos(U8 x, U8 y);
//*----------------------------------------------------------------------------
void Font_SystemFont(void);
void Font_HeaderFont(void);
void Font_BigFont(void);
//*----------------------------------------------------------------------------
#endif
